# VariableScopeValues

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**environments** | [**list[ReferenceDataItem]**](ReferenceDataItem.md) |  | [optional] 
**machines** | [**list[ReferenceDataItem]**](ReferenceDataItem.md) |  | [optional] 
**actions** | [**list[ReferenceDataItem]**](ReferenceDataItem.md) |  | [optional] 
**roles** | [**list[ReferenceDataItem]**](ReferenceDataItem.md) |  | [optional] 
**channels** | [**list[ReferenceDataItem]**](ReferenceDataItem.md) |  | [optional] 
**tenant_tags** | [**list[ReferenceDataItem]**](ReferenceDataItem.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


